==> aime_0.59.orig.tar.gz: aime-0.59.orig/include/utils.h <==
#ifndef _UTILS_H
#define _UTILS_H

#include <time.h>

#include "strings.h"

#ifndef CONVERTER
#include "errlog.h"
#include "mudobject.h"

class Inp_Handler;

char *get_time_str(void);
void get_date_str(Strings *time_str, time_t the_time);
int num_ats(char *the_str);
int make_full_area(Strings *the_string, char *the_area);
int encrypt_passwd(Strings *plain_text, Strings *encrypted_text);
int greater_than(char *first_str, char *second_str);
int data_log_on_pop(Inp_Handler *the_handler, char *player_name, 
            char *player_loc, char *data_log_name, Strings *the_string);
int test_malloc();
int check_specials(char *trig_name, MudObject *the_obj, 
                     MudObject *the_primary, MudObject *the_secondary, 
                                 MudObject *this_obj, Player *the_player);
int check_specials(char *trig_name, MudObject *the_obj, 
                 MudObject *the_primary, MudObject *the_secondary, 
                 MudObject *this_obj, Player *the_player, char *target_text);
int run_command(MudObject *the_user, char *command_str);
int enter_new_player(Inp_Handler *the_handler, char *player_name, 
                    char *not_used1, char *not_used2, Strings *not_used3);
int test_failure(char *player_name, int test_num);
MudObject *get_indicated_param(char *param_name, Specials *the_special,
                               char *function_name, Player *the_player,
                               in_params *player_params);
int get_stat_bonus(int the_stat);
char *get_rand_word(Strings *the_list);
vars *find_var(special_env *environment, char *var_name);
vars *get_var(special_env *environment, char *var_name);
int delete_var_list(special_env *environment);
int is_ignore_word(char *the_str);
int find_pos_in_list(char *the_list[], char *find_str);
char *str_sep( char **acStr, char *acDelim );
int sysmessage(char *new_str, ...);
int prompt_user_convert(char *filename, char *directory);
int test_funct();
int file_exists(char *the_file);
void fault(char *the_str);

#endif
// All functions used by the converter go after the endif above

class ErrLog;
class Entity;

char *read_desc_type(FILE *read_file, ErrLog *error_log, Entity *the_obj);


#endif

==> aime_0.60.3.orig.tar.gz: aime-0.60.3.orig/include/utils.h <==
#ifndef _UTILS_H
#define _UTILS_H

#include <time.h>

#include "strings.h"

#ifndef CONVERTER
#include "errlog.h"
#include "mudobject.h"

class Inp_Handler;

char *get_time_str(void);
void get_date_str(Strings *time_str, time_t the_time);
int num_ats(char *the_str);
int make_full_area(Strings *the_string, char *the_area);
int encrypt_passwd(Strings *plain_text, Strings *encrypted_text);
int greater_than(char *first_str, char *second_str);
int data_log_on_pop(Inp_Handler *the_handler, char *player_name, 
            char *player_loc, char *data_log_name, Strings *the_string);
int test_malloc();
int check_specials(char *trig_name, MudObject *the_obj, 
                     MudObject *the_primary, MudObject *the_secondary, 
                                 MudObject *this_obj, Individual *the_user);
int check_specials(char *trig_name, MudObject *the_obj, 
                 MudObject *the_primary, MudObject *the_secondary, 
                 MudObject *this_obj, Individual *the_user, char *target_text);
int run_command(MudObject *the_user, char *command_str);
int enter_new_player(Inp_Handler *the_handler, char *player_name, 
                    char *not_used1, char *not_used2, Strings *not_used3);
int test_failure(char *player_name, int test_num);
MudObject *get_indicated_param(char *param_name, Specials *the_special,
                               char *function_name, Individual *the_user,
                               in_params *player_params);
int get_stat_bonus(int the_stat);
char *get_rand_word(Strings *the_list);
vars *find_var(special_env *environment, char *var_name);
vars *get_var(special_env *environment, char *var_name);
int delete_var_list(special_env *environment);
int is_ignore_word(char *the_str);
int find_pos_in_list(char *the_list[], char *find_str);
char *str_sep( char **acStr, char *acDelim );
int sysmessage(char *new_str, ...);
int prompt_user_convert(char *filename, char *directory);
int test_funct();
int file_exists(char *the_file);
void fault(char *the_str);

#endif
// All functions used by the converter go after the endif above

class ErrLog;
class Entity;

char *read_desc_type(FILE *read_file, ErrLog *error_log, Entity *the_obj);


#endif
